<?php
/**
 * Astra Child Theme functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Astra Child
 * @since 1.0.0
 */

/**
 * Define Constants
 */
define( 'CHILD_THEME_ASTRA_CHILD_VERSION', '1.0.0' );

/**
 * Enqueue styles
 */
function child_enqueue_styles() {

	wp_enqueue_style( 'astra-child-theme-css', get_stylesheet_directory_uri() . '/style.css', array('astra-theme-css'), CHILD_THEME_ASTRA_CHILD_VERSION, 'all' );
	wp_enqueue_script( 'astra-child-theme-js', get_stylesheet_directory_uri() . '/js/js-functions.js', array('jquery'), '1.0.0', true );

}

add_action( 'wp_enqueue_scripts', 'child_enqueue_styles', 15 );

add_action( 'admin_enqueue_scripts', 'child_enqueue_admin_style' );
function child_enqueue_admin_style() {
    wp_enqueue_style( 'astra-child-theme-admin_css', get_stylesheet_directory_uri() . '/admin/admin-style.css', false, '1.0.0' );
}

add_action( 'after_setup_theme', 'reg_child_theme_image_sizes' );
function reg_child_theme_image_sizes() {
    add_image_size( 'post-thumb', 380, 250, true );
    add_image_size( 'post-large-thumb', 900, 580, true );
}

add_action( 'admin_init', 'reg_child_theme_remove_menu_pages' );
function reg_child_theme_remove_menu_pages() {
    remove_menu_page( 'cool-plugins-events-addon' ); 
}

require_once get_stylesheet_directory() . '/include/template-out.php';

function astra_settings_import(){
    global $wp_filesystem;

    $import_file = trailingslashit( get_stylesheet_directory() ) . 'demo-content/agency-demo/astra-settings-export.json';

    if ( empty( $wp_filesystem ) ) {
        require_once ABSPATH . '/wp-admin/includes/file.php';
        WP_Filesystem();
    }
    // Retrieve the settings from the file and convert the json object to an array.
    $file_contants = $wp_filesystem->get_contents( $import_file );
    $settings      = json_decode( $file_contants, 1 );

    // Astra addons activation.
    if ( class_exists( 'Astra_Admin_Helper' ) ) {
        Astra_Admin_Helper::update_admin_settings_option( '_astra_ext_enabled_extensions', $settings['astra-addons'] );
    }

    delete_option( 'astra-settings' );
	
	if ( ! empty( $settings['customizer-settings'] ) ) {
		foreach ( $settings['customizer-settings'] as $option => $value ) {
			update_option( $option, $value );
		}
	}
}

function wp_forms_lite_import(){
    global $wp_filesystem;

    $import_file = trailingslashit( get_stylesheet_directory() ) . 'demo-content/agency-demo/wpforms-forms-export.json';

    if ( empty( $wp_filesystem ) ) {
        require_once ABSPATH . '/wp-admin/includes/file.php';
        WP_Filesystem();
    }
    // Retrieve the settings from the file and convert the json object to an array.
    $file_contants = $wp_filesystem->get_contents( $import_file );
    $forms      = json_decode( $file_contants, 1 );

    if ( ! empty( $forms ) || is_array( $forms ) ) {
        foreach ( $forms as $form ) {
            $title  = ! empty( $form['settings']['form_title'] ) ? $form['settings']['form_title'] : '';
            $desc   = ! empty( $form['settings']['form_desc'] ) ? $form['settings']['form_desc'] : '';
            $new_id = wp_insert_post(
                [
                    'post_title'   => $title,
                    'post_status'  => 'publish',
                    'post_type'    => 'wpforms',
                    'post_excerpt' => $desc,
                ]
            );

            if ( $new_id ) {
                $form['id'] = $new_id;

                wp_update_post(
                    [
                        'ID'           => $new_id,
                        'post_content' => wpforms_encode( $form ),
                    ]
                );
            }
        }
    }
}

function clean_elementor_library () {
  $args = array (
    'post_type' => 'elementor_library',
    'nopaging' => true
  );
  $query = new WP_Query ($args);
  while ($query->have_posts ()) {
    $query->the_post();
    $id = get_the_ID();
    wp_delete_post ($id, true);
  }
  wp_reset_postdata ();
}

function ocdi_before_content_import( $selected_import ) {
    //clean_elementor_library();
    update_option( 'elementor_active_kit', 9999 );
}
add_action( 'ocdi/before_content_import', 'ocdi_before_content_import' );

function ocdi_register_plugins( $plugins ) {
  $theme_plugins = [
    [
      'name'     => 'Elementor Website Builder',
      'slug'     => 'elementor',
      'required' => true,
    ],
    [
      'name'     => 'Classic Editor',
      'slug'     => 'classic-editor',
      'required' => true,
    ],
    [
      'name'     => 'The Events Calendar',
      'slug'     => 'the-events-calendar',
      'required' => true,
    ],
    [
      'name'     => 'Events Shortcodes and Templates Addon',
      'slug'     => 'template-events-calendar',
      'required' => true,
    ],
    [
      'name'     => 'WPForms Lite',
      'slug'     => 'wpforms-lite',
      'required' => true,
    ],
    [
      'name'     => 'Yoast Duplicate Post',
      'slug'     => 'duplicate-post',
      'required' => true,
    ]
  ];
 
  return array_merge( $plugins, $theme_plugins );
}
add_filter( 'ocdi/register_plugins', 'ocdi_register_plugins' );

function ocdi_import_files() {
    return array(
        array(
            'import_file_name'           => 'Demo Agency Import',
            'categories'                 => array( 'Agency' ),
            'local_import_file'            => trailingslashit( get_stylesheet_directory() ) . 'demo-content/agency-demo/demo-content.xml',
            'local_import_widget_file'     => trailingslashit( get_stylesheet_directory() ) . 'demo-content/agency-demo/widgets.json',
            'local_import_customizer_file' => trailingslashit( get_stylesheet_directory() ) . 'demo-content/agency-demo/customizer.dat',
            'import_redux'               => array(),
            'import_preview_image_url'   => get_stylesheet_directory_uri() . '/demo-content/agency-demo/agency-preview.png',
            'import_notice'              => __( 'After you import this demo, you will have to Replace URLs in Elementor Tools & Save permalink settings.', 'your-textdomain' ),
            'preview_url'                => 'https://ashrae.website/',
        )
    );
}
add_filter( 'ocdi/import_files', 'ocdi_import_files' );

function ocdi_after_import_setup() {
   update_option( 'elementor_active_kit', 9999 );
   update_option( 'elementor_disable_color_schemes', 'yes' );
   update_option( 'elementor_disable_typography_schemes', 'yes' );
   
   $main_menu = get_term_by( 'name', 'Main', 'nav_menu' );
   $mobile_menu = get_term_by( 'name', 'Mobile Menu', 'nav_menu' );
   set_theme_mod( 'nav_menu_locations', [
            'primary' => $main_menu->term_id,
            'mobile_menu' => $mobile_menu->term_id,
        ]
   );
   
   astra_settings_import();
   
   wp_forms_lite_import();
   
    // Assign front page and posts page (blog page).
    $front_page_id = get_page_by_title( 'Home' );
 
    update_option( 'show_on_front', 'page' );
    update_option( 'page_on_front', $front_page_id->ID );
}
add_action( 'ocdi/after_import', 'ocdi_after_import_setup' );

add_filter('body_class', 'custom_body_class');
function custom_body_class($classes) {
    global $post;
    if(!empty($post->post_password) && post_password_required()){
        $classes[] = 'password-protected-page';
    }
    return $classes;
}

add_action( 'astra_entry_content_before','swastra_get_pass_prot_title', 80 );
function swastra_get_pass_prot_title(){
    global $post;
    if(!empty($post->post_password) && post_password_required()){
        $classes = get_body_class();
        if (preg_grep('/^elementor-page\s.*/', $classes)) {
            echo '<h1 class="entry-title" itemprop="headline">'.get_the_title($post->ID).'</h1>';
        }
    }
}

function get_post_id_by_slug( $slug, $post_type ) {
    $id = '';
    $query = new WP_Query(
        array(
            'name' => $slug,
            'post_type' => $post_type
        )
    );
    if($query->have_posts()){
        $query->the_post();
        $id = get_the_ID();
    }
    wp_reset_postdata();
    return $id;
}

function get_layout_type_dropdown(){
    $exclude = get_post_id_by_slug('default-kit', 'elementor_library');
    $lposts = get_posts(
        array(
            'post_type'  => 'elementor_library',
            'exclude'    => array($exclude),
            'numberposts' => -1
        )
    );
    if( ! $lposts ) return;

    $out = [];
    foreach( $lposts as $p )
    {
        $out[$p->ID] = __(esc_html( $p->post_title ), 'shiftweb_astra');
    }
    return $out;
}

function cc_mime_types($mimes) {
  $mimes['svg'] = 'image/svg+xml';
  return $mimes;
}
add_filter('upload_mimes', 'cc_mime_types');

function shiftweb_astra_customize_register( $wp_customize ) {

// Create our panels

$wp_customize->add_panel( 'shiftweb_astra_child_options', array(
    'priority'       => 10,
    'title'          => __('ShiftWeb Astra Child Theme Options', 'shiftweb_astra'),
    'description'    => __('ShiftWeb Astra Child Theme Options for theme sections Header Footer etc', 'shiftweb_astra'),
) );
        
// Create our sections

$wp_customize->add_section( 'swastra_top_header_section' , array(
    'title'             => __('Top Header', 'shiftweb_astra'),
    'priority'          => 20,
	'description'       => __('Select Top Header Layout from Elementor Saved Template Layouts', 'shiftweb_astra'),
) );
        
$wp_customize->add_section( 'swastra_main_footer_section' , array(
    'title'             => __('Main Footer', 'shiftweb_astra'),
    'priority'          => 61,
    'description'       => __('Select Main Footer Layout from Elementor Saved Template Layouts', 'shiftweb_astra'),
) );
        
// Create our settings

$wp_customize->add_setting( 'swastra_child_top_header' , array(
    'type'          => 'theme_mod',
    'transport'     => 'refresh',
) );
$wp_customize->add_control( 'swastra_child_top_header_control', array(
    'label'      => __('Top Header Layout', 'shiftweb_astra'),
    'description'=> __('Select from Drop Down', 'shiftweb_astra'),
    'section'    => 'swastra_top_header_section',
    'settings'   => 'swastra_child_top_header',
    'type'       => 'select',
        'choices'    => get_layout_type_dropdown(),
) );
        
$wp_customize->add_setting( 'swastra_child_main_footer' , array(
    'type'          => 'theme_mod',
    'transport'     => 'refresh',
) );
$wp_customize->add_control( 'swastra_child_main_footer_control', array(
    'label'      => __('Main Footer Layout', 'shiftweb_astra'),
	'description'=> __('Select from Drop Down', 'shiftweb_astra'),
    'section'    => 'swastra_main_footer_section',
    'settings'   => 'swastra_child_main_footer',
    'type'       => 'select',
        'choices'    => get_layout_type_dropdown(),
) );
        
}
add_action( 'customize_register', 'shiftweb_astra_customize_register', 30 );

add_filter( 'manage_elementor_library_posts_columns', 'set_custom_edit_elementor_library_columns' );
function set_custom_edit_elementor_library_columns($columns) {
    $columns['layout_shortcode'] = __( 'Shortcode', 'your_text_domain' );

    return $columns;
}

add_action( 'manage_elementor_library_posts_custom_column' , 'custom_elementor_library_column', 10, 2 );
function custom_elementor_library_column( $column, $post_id ) {
    switch ( $column ) {

        case 'layout_shortcode' :
            $code = '<input type="text"'.'value="'.'[template_out id='.$post_id.']'.'" readonly>';
            if ( is_string( $code ) )
                echo $code;
            else
                _e( 'Code not generated.', 'your_text_domain' );
            break;

    }
}

add_action( 'astra_main_header_bar_top','swastra_get_top_header_layout' );
function swastra_get_top_header_layout(){
    $top_header_layout = get_theme_mod( 'swastra_child_top_header' );
    if( $top_header_layout != '' ){
        echo do_shortcode('[template_out id="'.$top_header_layout.'"]');
    }
    else{
        $top_header_id = get_post_id_by_slug('top-header', 'elementor_library');
        echo do_shortcode('[template_out id="'.$top_header_id.'"]');
    }
}

add_action( 'astra_footer_before','swastra_get_main_footer_layout' );
function swastra_get_main_footer_layout(){
    $main_footer_layout = get_theme_mod( 'swastra_child_main_footer' );
    if( $main_footer_layout != '' ){
        echo do_shortcode('[template_out id="'.$main_footer_layout.'"]');
    }
    else{
        $main_footer_id = get_post_id_by_slug('main-footer', 'elementor_library');
        echo do_shortcode('[template_out id="'.$main_footer_id.'"]');
    }
}

add_shortcode( 'copyright_year', 'copyright_year_func' );
function copyright_year_func( $atts ) {
    return date("Y");
}

add_shortcode( 'get_latest_posts', 'get_latest_posts_func' );
function get_latest_posts_func( $atts ) {
    $args = array(
        'post_type'  => 'post',
        'posts_per_page' => 3,
        'orderby' => 'date',
        'order'   => 'DESC',
    );
    $out = '<div class="latest-posts">';
    $post_query = new WP_Query( $args );
    if ( $post_query->have_posts() ) {
        while ( $post_query->have_posts() ) {
            $post_query->the_post();
            $post_id = $post_query->post->ID;
            $title = get_the_title();
            $post_date = get_the_date( 'F j, Y' );
            $link = get_permalink();
            $excerpt = get_the_excerpt();
            $excerpt_out = '';
            $image_out = '';
            if (has_post_thumbnail( $post_id ) ){
                $image = wp_get_attachment_image_src( get_post_thumbnail_id( $post_id ), 'post-thumb' );
                $image_out .= '<div class="action-box">
                                <img src="'.$image[0].'" alt="">
                            </div>';
            }
            if($excerpt != ''){
                $excerpt_out .= '<p>' . $excerpt . '</p>';
            }
            $out .= '<div class="recent-news">
                        '. $image_out .'
                        <div class="info-bx">
                            <ul class="media-post">
                                <li class="date"><a href=""><i class="fa fa-calendar-o"></i>'. $post_date .'</a></li>
                            </ul>
                            <h4 class="post-title"><a href="'. $link .'">' . $title . '</a></h4>
                            '. $excerpt_out .'
                            <div class="post-extra">
                                <a href="'. $link .'" class="btn-link black radius-xl">READ MORE</a>
                            </div>
                        </div>
                    </div>';
        }
        wp_reset_postdata();
    }
    else{
        $out .= '<div><p>No Posts found</p></div>';
    }
    $out .= '</div>';
    return $out;
}

function get_numeric_posts_nav($post_query) {
    $out = '';
	
    if( $post_query->max_num_pages <= 1 )
        return;
 
    $paged = get_query_var( 'paged' ) ? absint( get_query_var( 'paged' ) ) : 1;
    $max   = intval( $post_query->max_num_pages );
 
    /** Add current page to the array */
    if ( $paged >= 1 )
        $links[] = $paged;
 
    /** Add the pages around the current page to the array */
    if ( $paged >= 3 ) {
        $links[] = $paged - 1;
        $links[] = $paged - 2;
    }
 
    if ( ( $paged + 2 ) <= $max ) {
        $links[] = $paged + 2;
        $links[] = $paged + 1;
    }
 
    $out .= '<div class="navigation"><ul>' . "\n";
 
    /** Previous Post Link */
    if ( get_previous_posts_link() )
        $out .= sprintf( '<li>%s</li>' . "\n", get_previous_posts_link() );
 
    /** Link to first page, plus ellipses if necessary */
    if ( ! in_array( 1, $links ) ) {
        $class = 1 == $paged ? ' class="active"' : '';
 
        $out .= sprintf( '<li%s><a href="%s">%s</a></li>' . "\n", $class, esc_url( get_pagenum_link( 1 ) ), '1' );
 
        if ( ! in_array( 2, $links ) )
            $out .= '<li>…</li>';
    }
 
    /** Link to current page, plus 2 pages in either direction if necessary */
    sort( $links );
    foreach ( (array) $links as $link ) {
        $class = $paged == $link ? ' class="active"' : '';
        $out .= sprintf( '<li%s><a href="%s">%s</a></li>' . "\n", $class, esc_url( get_pagenum_link( $link ) ), $link );
    }
 
    /** Link to last page, plus ellipses if necessary */
    if ( ! in_array( $max, $links ) ) {
        if ( ! in_array( $max - 1, $links ) )
            $out .= '<li>…</li>' . "\n";
 
        $class = $paged == $max ? ' class="active"' : '';
        $out .= sprintf( '<li%s><a href="%s">%s</a></li>' . "\n", $class, esc_url( get_pagenum_link( $max ) ), $max );
    }
 
    /** Next Post Link */
    if ( get_next_posts_link() )
        $out .= sprintf( '<li>%s</li>' . "\n", get_next_posts_link() );
 
    $out .= '</ul></div>' . "\n";
    
    return $out;
}

add_shortcode( 'get_all_posts', 'get_all_posts_func' );
function get_all_posts_func( $atts ) {
    $atts = shortcode_atts( array(
        'posts_per_page' => '',
    ), $atts );
    
    $posts_per_page = $atts['posts_per_page'];
	$paged = (get_query_var('paged')) ? get_query_var('paged') : 1;
    
    $args = array(
        'post_type'  => 'post',
        'orderby' => 'date',
        'posts_per_page' => ($posts_per_page != '' ? (int)$posts_per_page : '10'),
		'paged' => $paged,
        'order'   => 'DESC',
    );
    $out = '<div class="all-blog-posts">';
    $post_query = new WP_Query( $args );
    if ( $post_query->have_posts() ) {
        while ( $post_query->have_posts() ) {
            $post_query->the_post();
            $post_id = $post_query->post->ID;
            $title = get_the_title();
            $post_date = get_the_date( 'F j, Y' );
            $link = get_permalink();
            $excerpt = get_the_excerpt();
            $excerpt_out = '';
            $image_out = '';
            if (has_post_thumbnail( $post_id ) ){
                $image = wp_get_attachment_image_src( get_post_thumbnail_id( $post_id ), 'post-large-thumb' );
                $image_out .= '<div class="action-box">
                                <img src="'.$image[0].'" alt="">
                            </div>';
            }
            if($excerpt != ''){
                $excerpt_out .= '<p>' . $excerpt . '</p>';
            }
            $out .= '<div class="recent-news">
                        '. $image_out .'
                        <div class="info-bx">
                            <ul class="media-post">
                                <li class="date"><a href=""><i class="fa fa-calendar-o"></i>'. $post_date .'</a></li>
                            </ul>
                            <h4 class="post-title"><a href="'. $link .'">' . $title . '</a></h4>
                            '. $excerpt_out .'
                            <div class="post-extra">
                                <a href="'. $link .'" class="btn-link black radius-xl">READ MORE</a>
                            </div>
                        </div>
                    </div>';
        }
        $out .= get_numeric_posts_nav($post_query);
        wp_reset_postdata();
    }
    else{
        $out .= '<div><p>No Posts found</p></div>';
    }
    $out .= '</div>';
    return $out;
}

add_action( 'pre_get_posts', 'events_category_post_filter' );
function events_category_post_filter($query) {
    if ( ! is_admin() && in_array ( $query->get('post_type'), array('tribe_events') ) && is_post_type_archive('tribe_events') && ! is_tax() ) {
        $taxquery = array(
            array(
                'taxonomy' => 'tribe_events_cat',
                'field' => 'slug',
                'terms' => 'events',
            )
        );
        
        $query->set( 'tax_query', $taxquery );
        
        return;
    }
}

function get_post_by_title($page_title, $post_type ='post' , $output = OBJECT) {
    global $wpdb;
        $post = $wpdb->get_var( $wpdb->prepare( "SELECT ID FROM $wpdb->posts WHERE post_title = %s AND post_type= %s", $page_title, $post_type));
        if ( $post )
            return get_post($post, $output);

    return null;
}

add_shortcode( 'get_wp_forms_by_name', 'get_wp_forms_by_name_func' );
function get_wp_forms_by_name_func( $atts ) {
    $atts = shortcode_atts( array(
        'name' => '',
    ), $atts );
    
    $form_name = $atts['name'];
    
    if($form_name != ''){
      $form = get_post_by_title($form_name, 'wpforms');
      $form_id = $form->ID;
    }
 
    return do_shortcode('[wpforms id="'.$form_id.'"]');
}